==> luckybackup_0.3.5.orig.tar.gz: luckybackup-0.3.5/src/helpBrowser.cpp <==
// ---------------------------------- helpBrowser.cpp ---------------------------------------------------------------------------
// Class to display the project manual in a browser

//===============================================================================================================================
//===============================================================================================================================
//     This file is part of "luckyBackup" project
//     Copyright 2008-2009, Loukas Avgeriou
//     luckyBackup is distributed under the terms of the GNU General Public License
//     luckyBackup is free software: you can redistribute it and/or modify
//     it under the terms of the GNU General Public License as published by
//     the Free Software Foundation, either version 3 of the License, or
//     (at your option) any later version.
// 
//     luckyBackup is distributed in the hope that it will be useful,
//     but WITHOUT ANY WARRANTY; without even the implied warranty of
//     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//     GNU General Public License for more details.
// 
//     You should have received a copy of the GNU General Public License
//     along with luckyBackup.  If not, see <http://www.gnu.org/licenses/>.

// project version	: Please see "main.cpp" for project version

// developer 		: luckyb 
// last modified 	: 03 April 2009
//===============================================================================================================================
//===============================================================================================================================

#include "helpBrowser.h"

// class helpBrowser Constructor=================================================================================================
// Displays a simple dialog for browsing manual/index.html
helpBrowser::helpBrowser (QUrl helpUrl, QDialog *parent) : QDialog (parent)
{
	uiB.setupUi(this);
	//connect okay pushButton SLOTs ----------------
	connect ( uiB.button_ok, SIGNAL( clicked() ), this, SLOT( okay() ) );
	uiB.browser -> setOpenLinks(TRUE);
	uiB.browser -> setOpenExternalLinks(FALSE);
	uiB.browser -> setSource(helpUrl);
}
// SLOTS-------------------------------------------------------------------------------------
// --------------------------------okay pressed------------------------------------------------
void helpBrowser::okay()
{
	close();
}

// end of helpBrowser.cpp ---------------------------------------------------------------------------

==> luckybackup_0.4.4.orig.tar.gz: luckybackup-0.4.4/src/helpBrowser.cpp <==
// ---------------------------------- helpBrowser.cpp ---------------------------------------------------------------------------
// Class to display the project manual in a browser

//===============================================================================================================================
//===============================================================================================================================
//     This file is part of "luckyBackup" project
//     Copyright 2008-2010, Loukas Avgeriou
//     luckyBackup is distributed under the terms of the GNU General Public License
//     luckyBackup is free software: you can redistribute it and/or modify
//     it under the terms of the GNU General Public License as published by
//     the Free Software Foundation, either version 3 of the License, or
//     (at your option) any later version.
// 
//     luckyBackup is distributed in the hope that it will be useful,
//     but WITHOUT ANY WARRANTY; without even the implied warranty of
//     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//     GNU General Public License for more details.
// 
//     You should have received a copy of the GNU General Public License
//     along with luckyBackup.  If not, see <http://www.gnu.org/licenses/>.

// project version	: Please see "main.cpp" for project version

// developer 		: luckyb 
// last modified 	: 03 April 2009
//===============================================================================================================================
//===============================================================================================================================

#include "helpBrowser.h"

// class helpBrowser Constructor=================================================================================================
// Displays a simple dialog for browsing manual/index.html
helpBrowser::helpBrowser (QUrl helpUrl, QWidget *parent) : QDialog (parent)
{
	uiB.setupUi(this);
	//connect okay pushButton SLOTs ----------------
	connect ( uiB.button_ok, SIGNAL( clicked() ), this, SLOT( okay() ) );
	uiB.browser -> setOpenLinks(TRUE);
	uiB.browser -> setOpenExternalLinks(FALSE);
	uiB.browser -> setSource(helpUrl);
}
// SLOTS-------------------------------------------------------------------------------------
// --------------------------------okay pressed------------------------------------------------
void helpBrowser::okay()
{
	close();
}

// end of helpBrowser.cpp ---------------------------------------------------------------------------
